<?php

namespace Thaolx\TrialPackage\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Thaolx\TrialPackage\Interfaces\TrialpackageRepositoryInterface;
use Thaolx\TrialPackage\Repositories\Presenter\TrialpackageItemTransformer;

/**
 * Pubic API controller class.
 */
class TrialpackagePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Thaolx\Trialpackage\Interfaces\TrialpackageRepositoryInterface $trialpackage
     *
     * @return type
     */
    public function __construct(TrialpackageRepositoryInterface $trialpackage)
    {
        $this->repository = $trialpackage;
        parent::__construct();
    }

    /**
     * Show trialpackage's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $trialpackages = $this->repository
            ->setPresenter('\\Thaolx\\TrialPackage\\Repositories\\Presenter\\TrialpackageListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $trialpackages['code'] = 2000;
        return response()->json($trialpackages)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show trialpackage.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $trialpackage = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($trialpackage)) {
            $trialpackage         = $this->itemPresenter($module, new TrialpackageItemTransformer);
            $trialpackage['code'] = 2001;
            return response()->json($trialpackage)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
