<?php

namespace Thaolx\TrialPackage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Thaolx\TrialPackage\Models\Trialpackage;

class TrialpackagePolicy
{

    /**
     * Determine if the given user can view the trialpackage.
     *
     * @param UserPolicy $user
     * @param Trialpackage $trialpackage
     *
     * @return bool
     */
    public function view(UserPolicy $user, Trialpackage $trialpackage)
    {
        if ($user->canDo('trial_package.trialpackage.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $trialpackage->user_id;
    }

    /**
     * Determine if the given user can create a trialpackage.
     *
     * @param UserPolicy $user
     * @param Trialpackage $trialpackage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('trial_package.trialpackage.create');
    }

    /**
     * Determine if the given user can update the given trialpackage.
     *
     * @param UserPolicy $user
     * @param Trialpackage $trialpackage
     *
     * @return bool
     */
    public function update(UserPolicy $user, Trialpackage $trialpackage)
    {
        if ($user->canDo('trial_package.trialpackage.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $trialpackage->user_id;
    }

    /**
     * Determine if the given user can delete the given trialpackage.
     *
     * @param UserPolicy $user
     * @param Trialpackage $trialpackage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Trialpackage $trialpackage)
    {
        if ($user->canDo('trial_package.trialpackage.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $trialpackage->user_id;
    }

    /**
     * Determine if the given user can verify the given trialpackage.
     *
     * @param UserPolicy $user
     * @param Trialpackage $trialpackage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Trialpackage $trialpackage)
    {
        if ($user->canDo('trial_package.trialpackage.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('trial_package.trialpackage.verify') 
        && $user->is('manager')
        && $trialpackage->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given trialpackage.
     *
     * @param UserPolicy $user
     * @param Trialpackage $trialpackage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Trialpackage $trialpackage)
    {
        if ($user->canDo('trial_package.trialpackage.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
